@@ -1,24 +1,13 @@
 /*
-    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_DAVCOLLECTIONSMULTIFETCHJOB_H
 #define KDAV_DAVCOLLECTIONSMULTIFETCHJOB_H
 
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include "davcollection.h"
 #include "davurl.h"
@@ -39,7 +28,7 @@ class DavCollectionsMultiFetchJobPrivate;
  * @note This class just combines multiple calls of DavCollectionsFetchJob
  *       into one job.
  */
-class KPIMKDAV_EXPORT DavCollectionsMultiFetchJob : public KJob
+class KDAV_EXPORT DavCollectionsMultiFetchJob : public KJob
 {
     Q_OBJECT
 
