@@ -1,30 +1,18 @@
 /*
-    Copyright (c) 2014 Gregory Oestreicher <greg@kamago.net>
+    SPDX-FileCopyrightText: 2014 Gregory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_DAVJOBBASE_H
 #define KDAV_DAVJOBBASE_H
 
-#include <memory>
-
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include <KJob>
 
+#include <QScopedPointer>
+
 class DavJobBasePrivate;
 
 namespace KDAV {
@@ -33,7 +21,7 @@ class Error;
 /**
  * @short base class for the jobs used by the resource.
  */
-class KPIMKDAV_EXPORT DavJobBase : public KJob
+class KDAV_EXPORT DavJobBase : public KJob
 {
     Q_OBJECT
 
@@ -95,8 +83,11 @@ protected:
     void setJobError(int jobErrorCode);
     void setErrorTextFromDavError();
     void setDavError(const Error &error);
+
+    explicit DavJobBase(DavJobBasePrivate *dd, QObject *parent = nullptr);
+    QScopedPointer<DavJobBasePrivate> d_ptr;
 private:
-    std::unique_ptr<DavJobBasePrivate> d;
+    Q_DECLARE_PRIVATE(DavJobBase)
 };
 }
 
