@@ -1,24 +1,13 @@
 /*
-    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
+    SPDX-FileCopyrightText: 2010 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_ETAGCACHE_H
 #define KDAV_ETAGCACHE_H
 
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include <QObject>
 #include <QStringList>
@@ -36,7 +25,7 @@ class EtagCachePrivate;
  * out which items have been changed in the backend and have to
  * be refetched on the next call of ResourceBase::retrieveItems()
  */
-class KPIMKDAV_EXPORT EtagCache : public QObject
+class KDAV_EXPORT EtagCache : public QObject
 {
     Q_OBJECT
 
